#!/usr/bin/env python

"""Install script for angel2vtk using SETUPTOOLS_ w/ windows post-installation.

This script uses the SETUPTOOLS_ of Python_ and therefore
at first search for it and import it if was found.  If NOT
then try to import easy_setup module which may be downloaded
from many places including `this URL`_ and be placed locally.

This script uses a class for installation which overrides
the original `install` in order to run additional post-
installation scripts, but at present the overriding class
just runs the original `install.

The following class is defined in this module

* :py:class:`my_install`.

In the ``__main__`` part of this module, the

* :py:func:`setup`

function of the SETUPTOOLS_ is invoked with keyword
arguments appropriate for this package.

.. note::
  In order to avoid the execution of `setup` function when
  imported by Sphinx_ , the function is placed in the usual
  ``if __name__ == "__main__":`` clause, which is **NOT** a
  *conventional* coding style.

  For details consult the following articles:

  * https://bitbucket.org/birkenfeld/sphinx/issue/1226
  * http://www.freia.jp/taka/blog/sphinx-dev-20140705/index.html (in Japanese)

.. warning::
  At present, angel2vtk uses the mc-tools_\ ' angel2root(.py).
  Also, we need to use PyEVTK_ to crate VTK_ files from Python_ .
  However, the author of this package could **NOT** make 
  ``install_requires`` and ``setup_requires`` work from SETUPTOOLS_ 
  although the URLs for the two packages are specified in
  ``dependency_link``.  Therefore, to install this package with
  the dependent ones, you should for example use PIP_ with the
  ``install.list`` file included in this package, rather than
  assuming that the dependency is properly set.

  With PIP_ but without the ``install.list`` file, one can install
  the two dependent packages as the following::
  
    $ pip install git+https://github.com/kbat/mc-tools.git#egg=mc-tools
    $ pip install hg+https://bitbucket.org/pauloh/pyevtk#egg=evtk

  Of course, to do these one should have Git_ (the former) as
  well as Mercurial_ (the latter) in hand.

.. moduleauthor:: Kazuyoshi Furutaka <furutaka.kazuyoshi@jaea.go.jp>
.. module:: setup.py
    :platform: Unix, Windows, etc. (arch. independent)
    :synopsis: The install configuration for angel2vtk.

.. _SETUPTOOLS: https://pypi.python.org/pypi/setuptools
.. _Python:     https://www.python.org
.. _`this URL`: https://bootstrap.pypa.io/ez_setup.py
.. _Sphinx:     http://sphinx-doc.org
.. _mc-tools:   https://github.com/kbat/mc-tools
.. _PyEVTK:     https://bitbucket.org/pauloh/pyevtk
.. _VTK:        http://www.vtk.org
.. _PIP:        https://pip.pypa.io/en/latest/
.. _Git:        http://git-scm.com
.. _Mercurial:  http://mercurial.selenic.com
"""

import sys, os, subprocess

progname = "angel2vtk"

# prepare setuptools environment
try:
    from setuptools import setup, find_packages
    from setuptools.command.install import install
except ImportError:
    print "Could NOT import setuptools, try ez_setup..."
    try:
        from ez_setup import use_setuptools
        use_setuptools()
        from setuptools import setup, find_packages
        from setuptools.command.install import install
    except ImportError:
        print "Could NOT import either setuptools or ez_setup, GIVE UP!"
        print "Download ez_setup.py e.g. " \
            "from https://bootstrap.pypa.io/ez_setup.py,"
        print "place it in the same directory as setup.py, and try again... "
        sys.exit(1)

class my_install(install):
    """Private install class with post-installation scripts in mind.

    There's only one method, :py:meth:`run`, which overrides the
    original: at present it just runs the corresponding inherited
    method.
    """
    def run(self):
        """Overriding/extending ``run`` method.

        Just run the parent's method at present.
        """
        install.run(self) # the "original" install
        # Custom stuff here
        # distutils.command.install actually has some nice helper methods
        # and interfaces. I strongly suggest reading the docstrings.

if __name__ == "__main__":
    setup(
        name = progname,
        version = "1.0.2.post5",
        author = "Kazuyoshi Furutaka",
        author_email = "furutaka.kazuyoshi@jaea.go.jp",
        url = "http://cool1.tokai-sc.jaea.go.jp/DCASwiki/",
	license = "LGPLv2.1",
        
        packages = find_packages(),
        scripts = ["angel2vtk/postinst.py"] if "win" in sys.platform else [], 
        data_files = [('/usr/share/applications', 
                       ['%s.desktop' % progname]),] if not "win" in sys.platform else [],
        cmdclass={'install': my_install}, # do extended install defined above
        
        # {install,setup}_requires and dependency_links:
        #
        install_requires = [ 'numpy', 'evtk', 'mc-tools' ],
        # setup_requires = [ 'evtk', 'mc-tools' ],
        dependency_links = [
            # mc-tools
            #   (git clone https://github.com/kbat/mc-tools.git )
            "git+https://github.com/kbat/mc-tools.git#egg=mc-tools",
            # PyEVTK
            "hg+https://bitbucket.org/pauloh/pyevtk#egg=evtk",
        ],

        # 'scripts' should list executable scripts in Distutil
        # scripts = [ '' ],
        entry_points = {
            "console_scripts" : [
                "%s = angel2vtk.angel:main" % progname,
            ],
            "gui_scripts" : [
                "%s.pyw = angel2vtk.angel:GUImain" % progname,
            ]
        }
        
    )
